@@ -26,15 +26,12 @@ pref("security.ssl3.rsa_1024_rc4_56_sha", false);
 pref("security.ssl3.rsa_1024_des_cbc_sha", false);
 pref("security.ssl3.rsa_rc4_40_md5", false);
 pref("security.ssl3.rsa_rc2_40_md5", false);
-// Camellia is broken on Windows CE for now, see bug 508113
-//@line 31 "/builds/slave/m-beta-osx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_dss_camellia_256_sha", true);
 pref("security.ssl3.rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_rsa_camellia_128_sha", true);
 pref("security.ssl3.dhe_dss_camellia_128_sha", true);
 pref("security.ssl3.rsa_camellia_128_sha", true);
-//@line 38 "/builds/slave/m-beta-osx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_aes_256_sha", true);
 pref("security.ssl3.dhe_dss_aes_256_sha", true);
 pref("security.ssl3.rsa_aes_256_sha", true);
@@ -181,7 +178,7 @@ pref("dom.indexedDB.warningQuota", 50);
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
 
-pref("browser.sessionhistory.optimize_eviction", false);
+pref("browser.sessionhistory.optimize_eviction", true);
 
 pref("ui.use_native_colors", true);
 pref("ui.use_native_popup_windows", false);
@@ -245,13 +242,16 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 512000);
 
-//@line 176 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
-pref("media.ogg.enabled", true);
+// Master HTML5 media volume scale.
+pref("media.volume_scale", "1.0");
+
 //@line 179 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
-pref("media.wave.enabled", true);
+pref("media.ogg.enabled", true);
 //@line 182 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+pref("media.wave.enabled", true);
+//@line 185 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 184 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 187 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -265,27 +265,24 @@ pref("gfx.color_management.rendering_intent", 0);
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 198 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
-pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", false);
-//@line 202 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 205 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 203 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // use harfbuzz for default (0x01) + arabic (0x02) + hebrew (0x04)
 pref("gfx.font_rendering.harfbuzz.scripts", 7);
-//@line 211 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 209 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 218 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 216 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 242 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 240 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 245 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 243 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -321,6 +318,11 @@ pref("toolkit.scrollbox.smoothScroll", true);
 pref("toolkit.scrollbox.scrollIncrement", 20);
 pref("toolkit.scrollbox.clickToScroll.scrollDelay", 150);
 
+// Telemetry
+pref("toolkit.telemetry.enabled", false);
+// Telemetry test server to be used until the official one is public
+pref("toolkit.telemetry.server", "http://telemetry.allizom.org");
+
 // view source
 pref("view_source.syntax_highlight", true);
 pref("view_source.wrap_long_lines", false);
@@ -630,9 +632,9 @@ pref("dom.min_timeout_value", 4);
 pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 590 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 593 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 592 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 595 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -647,14 +649,14 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 609 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 612 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
 pref("javascript.options.methodjit.content", true);
-pref("javascript.options.methodjit.chrome",  false);
+pref("javascript.options.methodjit.chrome",  true);
 pref("javascript.options.jitprofiling.content", true);
-pref("javascript.options.jitprofiling.chrome",  false);
+pref("javascript.options.jitprofiling.chrome",  true);
 pref("javascript.options.methodjit_always", false);
 // This preference limits the memory usage of javascript.
 // If you want to change these values for your device,
@@ -693,9 +695,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 655 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 658 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 657 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 660 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -742,8 +744,11 @@ pref("network.http.proxy.keep-alive", true);
 // the packet is lost or delayed on the route.
 pref("network.http.keep-alive.timeout", 115);
 
-// limit the absolute number of http connections.
-pref("network.http.max-connections", 30);
+// Limit the absolute number of http connections.
+// Note: the socket transport service will clamp the number below 256 if the OS
+// cannot allocate that many FDs, and it also always tries to reserve up to 250
+// file descriptors for things other than sockets.   
+pref("network.http.max-connections", 256);
 
 // limit the absolute number of http connections that can be established per
 // host.  if a http proxy server is enabled, then the "server" is the proxy
@@ -802,6 +807,11 @@ pref("network.http.prompt-temp-redirect", true);
 // Section 4.8 "High-Throughput Data Service Class"
 pref("network.http.qos", 0);
 
+// The number of milliseconds after sending a SYN for an HTTP connection,
+// to wait before trying a different connection. 0 means do not use a second
+// connection.
+pref("network.http.connection-retry-timeout", 250);
+
 // default values for FTP
 // in a DSCP environment this should be 40 (0x28, or AF11), per RFC-4594,
 // Section 4.8 "High-Throughput Data Service Class", and 80 (0x50, or AF22)
@@ -812,14 +822,42 @@ pref("network.ftp.control.qos", 0);
 // </http>
 
 // <ws>: WebSocket
-// The -76 websocket network protocol may be subject to HTTP cache poisoning
-// attacks. Until there is a secure open standard available and implemented
-// in necko the override-security-block preference must be set to true before
-// the normal enabled preference is considered. Bug 616733
-pref("network.websocket.override-security-block", false);
 pref("network.websocket.enabled", true);
+
+// mobile might want to set this much smaller
+pref("network.websocket.max-message-size", 16000000);
+
+// Should we automatically follow http 3xx redirects during handshake
+pref("network.websocket.auto-follow-http-redirects", false);
+
+// the number of seconds to wait for websocket connection to be opened
+pref("network.websocket.timeout.open", 20);
+
+// the number of seconds to wait for a clean close after sending the client
+// close message
+pref("network.websocket.timeout.close", 20);
+
+// the number of seconds of idle read activity to sustain before sending a
+// ping probe. 0 to disable.
+pref("network.websocket.timeout.ping.request", 0);
+
+// the deadline, expressed in seconds, for some read activity to occur after
+// generating a ping. If no activity happens then an error and unclean close
+// event is sent to the javascript websockets application
+pref("network.websocket.timeout.ping.response", 10);
+
+// Defines whether or not to try and negotiate the stream-deflate compression
+// extension with the websocket server
+pref("network.websocket.extensions.stream-deflate", false);
+
 // </ws>
 
+// Server-Sent Events
+
+pref("dom.server-events.enabled", true);
+// Equal to the DEFAULT_RECONNECTION_TIME_VALUE value in nsEventSource.cpp
+pref("dom.server-events.default-reconnection-time", 5000); // in milliseconds
+
 // If false, remote JAR files that are served with a content type other than
 // application/java-archive or application/x-jar will not be opened
 // by the jar channel.
@@ -864,6 +902,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -892,6 +931,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -901,11 +943,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -991,7 +1036,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 958 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1004 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1052,7 +1097,6 @@ pref("converter.html2txt.structs",          true); // Output structured phrases
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
 pref("intl.accept_languages",               "chrome://global/locale/intl.properties");
-pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.static",     "chrome://global/locale/intl.properties");
@@ -1082,6 +1126,11 @@ pref("intl.uidirection.ar", "rtl");
 pref("intl.uidirection.he", "rtl");
 pref("intl.uidirection.fa", "rtl");
 
+// use en-US hyphenation by default for content tagged with plain lang="en"
+pref("intl.hyphenation-alias.en", "en-us");
+// and for other subtags of en-*, if no specific patterns are available
+pref("intl.hyphenation-alias.en-*", "en-us");
+
 pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
@@ -1133,9 +1182,6 @@ pref("mousewheel.transaction.timeout", 1500);
 // mouse wheel scroll transaction is held even if the mouse cursor is moved.
 pref("mousewheel.transaction.ignoremovedelay", 100);
 
-// Macbook touchpad two finger pixel scrolling
-pref("mousewheel.enable_pixel_scrolling", true);
-
 // prefs for app level mouse wheel scrolling acceleration.
 // number of mousewheel clicks when acceleration starts
 // acceleration can be turned off if pref is set to -1
@@ -1246,12 +1292,6 @@ pref("bidi.numeral", 0);
 // 2 = OsBidisupport
 // 3 = disableBidisupport
 pref("bidi.support", 1);
-// ------------------
-//  Charset Mode
-// ------------------
-// 1 = doccharactersetBidi *
-// 2 = defaultcharactersetBidi
-pref("bidi.characterset", 1);
 // Whether delete and backspace should immediately delete characters not
 // visually adjacent to the caret, or adjust the visual position of the caret
 // on the first keypress and delete the character on a second keypress
@@ -1380,20 +1420,20 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1347 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1388 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1358 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1399 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1373 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1414 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1430,9 +1470,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1833 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1910 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1835 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1912 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1855,19 +1895,24 @@ pref("print.print_extra_margin", 90); // twips (90 twips is an eigth of an inch)
 // See bug 404131, topmost <panel> element wins to Dashboard on MacOSX.
 pref("ui.panel.default_level_parent", false);
 
+pref("ui.plugin.cancel_composition_at_input_source_changed", false);
+
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2261 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+// Macbook touchpad two finger pixel scrolling
+pref("mousewheel.enable_pixel_scrolling", true);
 
-//@line 2461 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2343 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2730 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2543 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3005 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2812 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3025 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3087 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3033 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3107 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+
+//@line 3115 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1941,9 +1986,9 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3112 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3194 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3117 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3199 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
 pref("layers.acceleration.disabled", false);
@@ -1951,13 +1996,13 @@ pref("layers.acceleration.disabled", false);
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3136 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3218 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
 // Enable/Disable the orientation API for content
-pref("accelerometer.enabled", true);
+pref("device.motion.enabled", true);
 
 // Enable/Disable HTML5 parser
 pref("html5.parser.enable", true);
